//
//  MOTextTableViewCell.m
//  MOSettingsTableView
//
//  Created by Jan Christiansen on 10/31/12.
//  Copyright (c) 2012 monoid - Software Development and Consulting - Jan Christiansen.
//  All rights reserved.
//
//  Redistribution and use in source and binary forms, with or without
//  modification, are permitted provided that the following conditions are met:
//
//  * Redistributions of source code must retain the above copyright
//  notice, this list of conditions and the following disclaimer.
//
//  * Redistributions in binary form must reproduce the above
//  copyright notice, this list of conditions and the following
//  disclaimer in the documentation and/or other materials provided
//  with the distribution.
//
//  * Neither the name of Monoid - Development and Consulting -
//  Jan Christiansen nor the names of other
//  contributors may be used to endorse or promote products derived
//  from this software without specific prior written permission.
//
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
//  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
//  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
//  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
//  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
//  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
//  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
//  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
//  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
//  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//

#import "MOChoiceTableViewCell.h"


static const float kRightCellMargin = 6;

static const float kRightLabelMargin = 10;


@interface MOChoiceTableViewCell ()


@property(strong, nonatomic) UILabel *choiceLabel;


@end


@implementation MOChoiceTableViewCell


- (id)initWithReuseIdentifier:(NSString *)reuseIdentifier {

    self = [super initWithStyle:UITableViewCellStyleDefault reuseIdentifier:reuseIdentifier];
    if (self) {
        _choiceLabel = [[UILabel alloc] initWithFrame:CGRectZero];
        _choiceLabel.textAlignment = NSTextAlignmentRight;
        _choiceLabel.textColor = [UIColor colorWithRed:0.17 green:0.25 blue:0.45 alpha:1];
        _choiceLabel.backgroundColor = [UIColor clearColor];
        [self.contentView addSubview:_choiceLabel];
        self.accessoryType = UITableViewCellAccessoryDisclosureIndicator;
        self.selectionStyle = UITableViewCellSelectionStyleBlue;
    }
    return self;
}


- (void)layoutSubviews {

    [super layoutSubviews];
    
    // calculate size of label to adjust size of text
    CGSize constraintSize = CGSizeMake(MAXFLOAT, MAXFLOAT);
    CGSize labelSize = [self.name sizeWithFont:self.textLabel.font
                             constrainedToSize:constraintSize
                                 lineBreakMode:UILineBreakModeMiddleTruncation];

    self.choiceLabel.frame = CGRectMake(self.textLabel.frame.origin.x + labelSize.width + kRightLabelMargin,
                                        10,
                                        self.contentView.bounds.size.width - (self.textLabel.frame.origin.x + labelSize.width + kRightLabelMargin + kRightCellMargin),
                                        23);
}


#pragma mark - Overloaded Setter and Getter

- (void)setChoice:(NSUInteger)choice {

    _choice = choice;
    self.choiceLabel.text = [self.choices objectAtIndex:choice];
}


@end
