//
//  MOSettingsViewController.h
//  MOSettingsTableView
//
//  Created by Jan Christiansen on 10/1/12.
//  Copyright (c) 2012 monoid - Software Development and Consulting - Jan Christiansen.
//  All rights reserved.
//
//  Redistribution and use in source and binary forms, with or without
//  modification, are permitted provided that the following conditions are met:
//
//  * Redistributions of source code must retain the above copyright
//  notice, this list of conditions and the following disclaimer.
//
//  * Redistributions in binary form must reproduce the above
//  copyright notice, this list of conditions and the following
//  disclaimer in the documentation and/or other materials provided
//  with the distribution.
//
//  * Neither the name of Monoid - Development and Consulting -
//  Jan Christiansen nor the names of other
//  contributors may be used to endorse or promote products derived
//  from this software without specific prior written permission.
//
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
//  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
//  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
//  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
//  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
//  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
//  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
//  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
//  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
//  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//

#import <UIKit/UIKit.h>

#import "MOSettingsSpecification.h"
#import "MOSettingTableViewCell.h"
#import "MOChoiceController.h"


@protocol MOSettingsDelegate <NSObject>


- (void)settingValueChangedWithName:(NSString *)name inGroup:(NSUInteger)group;


@end


/** the data source is used for settings whose value is not static but
 * additionally depends on an external source
 */
@protocol MOSettingsDataSource <NSObject>


@optional

- (id)settingForName:(NSString *)name inGroup:(NSUInteger)group;

- (BOOL)enableSettingForName:(NSString *)name inGroup:(NSUInteger)group;


@end


@interface MOSettingsTableViewController : UITableViewController <MOSettingTableViewCellDelegate,MOChoiceControllerDelegate>


@property(assign, nonatomic) id<MOSettingsDelegate> delegate;

@property(assign, nonatomic) id<MOSettingsDataSource> dataSource;

@property(assign, nonatomic) BOOL localizedStrings;

@property(assign, nonatomic) BOOL doneButtonHidden;


- (id)initWithCoder:(NSCoder *)aDecoder
  specificationFile:(NSString *)specificationFile;

- (id)initWithStyle:(UITableViewStyle)style
  specificationFile:(NSString *)filePath;

- (id)initWithStyle:(UITableViewStyle)style
      specification:(MOSettingsSpecification *)specification;


- (id)settingForName:(NSString *)name inGroup:(NSUInteger)group;

//- (void)setSetting:(id)value forName:(NSString *)name inGroup:(NSUInteger)group;

- (void)enableSetting:(BOOL)enabled
              forName:(NSString *)name
              inGroup:(NSUInteger)group;

- (void)reloadSettings;


@end
