//
//  MOSwitchTableViewCell.m
//  MOSettingsTableView
//
//  Created by Jan Christiansen on 10/1/12.
//  Copyright (c) 2012 monoid - Software Development and Consulting - Jan Christiansen.
//  All rights reserved.
//
//  Redistribution and use in source and binary forms, with or without
//  modification, are permitted provided that the following conditions are met:
//
//  * Redistributions of source code must retain the above copyright
//  notice, this list of conditions and the following disclaimer.
//
//  * Redistributions in binary form must reproduce the above
//  copyright notice, this list of conditions and the following
//  disclaimer in the documentation and/or other materials provided
//  with the distribution.
//
//  * Neither the name of Monoid - Development and Consulting -
//  Jan Christiansen nor the names of other
//  contributors may be used to endorse or promote products derived
//  from this software without specific prior written permission.
//
//  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
//  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
//  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
//  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
//  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
//  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
//  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
//  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
//  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
//  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
//  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//

#import "MOSwitchTableViewCell.h"


static const float kRightCellMargin = 8;


@interface MOSwitchTableViewCell ()


@property(strong, nonatomic) UISwitch *switcher;


@end


@implementation MOSwitchTableViewCell


- (id)initWithReuseIdentifier:(NSString *)reuseIdentifier {

    self = [super initWithStyle:UITableViewCellStyleDefault
                reuseIdentifier:reuseIdentifier];
    if (self) {
        _switcher = [[UISwitch alloc]initWithFrame:CGRectZero];
        [self.contentView addSubview:_switcher];
        [_switcher addTarget:self
                      action:@selector(switchChangedState)
            forControlEvents:UIControlEventValueChanged];
        self.selectionStyle = UITableViewCellSelectionStyleNone;
    }
    return self;
}

- (void)layoutSubviews {

    [super layoutSubviews];

    self.switcher.frame = CGRectMake(self.contentView.bounds.size.width - kRightCellMargin - self.switcher.bounds.size.width,
                                     0.5 * self.contentView.bounds.size.height - 0.5 * self.switcher.bounds.size.height,
                                     self.switcher.frame.size.width,
                                     self.switcher.frame.size.height);
}


#pragma mark - Actions

- (void)switchChangedState {

    [self.delegate cellChangedState:self];
}


#pragma mark - Overloaded Setter and Getter

- (BOOL)enabled {

    return self.switcher.isOn;
}

- (void)setEnabled:(BOOL)enabled {

    self.switcher.on = enabled;
}

- (BOOL)settingEnabled {

    return self.switcher.enabled;
}

- (void)setSettingEnabled:(BOOL)settingEnabled {

    self.switcher.enabled = settingEnabled;
}


@end
